from importlib.resources import files, as_file, read_binary
from pathlib import Path
import os
import cycler

from matplotlib import font_manager

from .colors import CAVS_cycle, CAVS_cycle_dark, CAVS_cubehelix, CAVS_colors



_font_paths = {os.path.splitext(os.path.basename(path))[0]:
         path for path in files("cavs_style.fonts").iterdir() 
         if os.path.splitext(path)[-1].lower() == ".ttf"}

for _fpath in _font_paths.values():
    font_manager.fontManager.addfont(os.fspath(_fpath))
         
         
CAVS_style = {"axes.prop_cycle":CAVS_cycle,
              "font.sans-serif":"Chivo",
              "mathtext.default":"regular",
              "figure.dpi":200, 
              "savefig.dpi":200,
              "savefig.transparent": True,
              "savefig.pad_inches": 0,
              "legend.fancybox": False,
              "image.cmap":"CAVS_blend"
              }

paper = {"font.size":10, "axes.linewidth":1}


dark = {"axes.prop_cycle":CAVS_cycle_dark,
           "text.color": CAVS_colors[3], 
           "savefig.transparent": False,
           "axes.facecolor":     CAVS_colors[1],
           "axes.edgecolor":     CAVS_colors[3],
           "axes.labelcolor":    CAVS_colors[3],
           "xtick.color": CAVS_colors[3],
           "ytick.color": CAVS_colors[3],
           "figure.facecolor":   CAVS_colors[1]}
                

single_column = {'figure.figsize':[3.5, 3.5*2/3]}

poster = {"font.size": 16,
         "axes.linewidth":     2}



from mpl_toolkits.axes_grid1 import make_axes_locatable, inset_locator


def ufuk_cax(div, horizontal_size="7%",pad="2%", vertical_size="30%"):
    axins = div.append_axes("right",horizontal_size,
                           pad=pad)
    axins.set_visible(False)
    cax = inset_locator.inset_axes(axins, 
                               width="100%", 
                               height=vertical_size, 
                               loc="lower left",
                              borderpad=0)
    return cax


def ufuk_cbar_format(cbar, adjust_label=True):
    if adjust_label:
        cbar.ax.yaxis.label.set_horizontalalignment("center")
        cbar.ax.yaxis.label.set_verticalalignment("bottom")
        cbar.ax.yaxis.label.set_rotation(0)
        cbar.ax.yaxis.set_label_coords(.5,1, transform=cbar.ax.transAxes)
    cbar.set_ticks([cbar.vmin, cbar.vmax])

